@@ -5,11 +5,12 @@
 
 from django.contrib import admin
 
-from .models import IdentityKey, SignedPreKey, PreKey, EncryptingSenderKey, DecryptingSenderKey, Party
+from .models import IdentityKey, SignedPreKey, PreKey, EncryptingSenderKey, DecryptingSenderKey, Party, PendingKey
 
 admin.site.register(IdentityKey)
 admin.site.register(SignedPreKey)
 admin.site.register(PreKey)
 admin.site.register(EncryptingSenderKey)
 admin.site.register(DecryptingSenderKey)
-admin.site.register(Party)
\ No newline at end of file
+admin.site.register(Party)
+admin.site.register(PendingKey)
\ No newline at end of file
