@@ -157,7 +157,9 @@ class StickProtocol():
         try:
             member = self.User.objects.get(id=memberId)
         except:
-            member = self.User.objects.get(oneTimeId=memberId)
+            member = self.User.objects.filter(oneTimeId=memberId).first()
+            if not member:
+                return {'partyExists': False}
 
         # You need to check whether the user is authorized to fetch that SenderKey
         authorized = False
@@ -179,8 +181,7 @@ class StickProtocol():
             else:
                 party = Party.objects.filter(id=stickId[:36]).first()
                 if not party:
-                    partyExists = False
-                    return {'partyExists': partyExists}
+                    return {'partyExists': False}
                 # A user connected with another user should be authorized
                 if party.user and (user in party.user.connections.all() or user.phone in party.user.contacts):
                     authorized = True
